@@ -115,7 +115,7 @@ impl Screen {
                     Left => self.select_left(),
                     Right => self.select_right(),
                     Backspace => self.backspace(),
-                    Char('\n') => self.toggle_collapsed(),
+                    Char('\n') => self.create_sibling(),
                     Char('\t') => self.create_child(),
                     Ctrl('v') => self.exec_selected(),
                     Ctrl('w') => self.drill_down(),
@@ -125,7 +125,7 @@ impl Screen {
                     Ctrl('h') => self.toggle_hide_stricken(),
                     Ctrl('r') => self.add_or_remove_arrow(),
                     Ctrl('p') => self.auto_arrange(),
-                    Ctrl('t') => self.create_sibling(),
+                    Ctrl('t') => self.toggle_collapsed(),
                     Ctrl('c') => return false,
                     Ctrl('x') => self.save(),
                     Ctrl('l') => self.toggle_show_logs(),
